==> jira_rest-8.x-2.0.tar.gz: jira_rest/src/Controller/JiraRestController.php <==
<?php
/**
 * @file
 * Contains \Drupal\jira_rest\Controller\JiraRestController.
 * providing methods for modifying
 * JIRA issues out of Drupal via REST.
 */

namespace Drupal\jira_rest\Controller;


use Drupal\jira_rest\JiraRestException;
use Drupal\Core\Controller\ControllerBase;
use Drupal\jira_rest\JiraRestWrapperService;
use Symfony\Component\DependencyInjection\ContainerInterface;


use biologis\JIRA_PHP_API;


/**
 * Jira_RestController.
 */
class JiraRestController extends ControllerBase {

  /**
   * @var \Drupal\jira_rest\JiraRestWrapperService
   */
  protected $jiraRestWrapperService;

  /**
   * Class constructor.
   */
  public function __construct($jira_rest_wrapper_service) {

    $this->jiraRestWrapperService = $jira_rest_wrapper_service;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('jira_rest_wrapper_service')
    );
  }

  /**
   * just for testing.
   */
  public function test() {

    //example for searching open tickets and returning the key of the first one found

    $search = $this->jiraRestWrapperService->getIssueService()->createSearch();
    // search for existing issue
    $search->search(utf8_encode("status = Open"));

    foreach ($search->getIssues() as $i){
      $issue = $i;
    }

    if(!empty($issue)){
      return array(
        '#markup' => t('Controller action test successful, found a jira issue with key:' . $issue->key),
      );
    }
    else {
      return array(
        '#markup' => t('Controller action test successful, but no open issue found'),
      );
    }


  }


}

==> jira_rest-8.x-2.1.tar.gz: jira_rest/src/Controller/JiraRestController.php <==
<?php
/**
 * @file
 * Contains \Drupal\jira_rest\Controller\JiraRestController.
 * providing methods for modifying
 * JIRA issues out of Drupal via REST.
 */

namespace Drupal\jira_rest\Controller;


use Drupal\jira_rest\JiraRestException;
use Drupal\Core\Controller\ControllerBase;
use Drupal\jira_rest\JiraRestWrapperService;
use Symfony\Component\DependencyInjection\ContainerInterface;


use biologis\JIRA_PHP_API;


/**
 * Jira_RestController.
 */
class JiraRestController extends ControllerBase {

  /**
   * @var \Drupal\jira_rest\JiraRestWrapperService
   */
  protected $jiraRestWrapperService;

  /**
   * Class constructor.
   */
  public function __construct($jira_rest_wrapper_service) {

    $this->jiraRestWrapperService = $jira_rest_wrapper_service;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('jira_rest_wrapper_service')
    );
  }

  /**
   *  example for searching open tickets and returning the key of the first one found.
   */
  public function test() {

    $search = $this->jiraRestWrapperService->getIssueService()->createSearch();
    // search for existing open issues
    $search->search(utf8_encode("status = Open"));

    foreach ($search->getIssues() as $i){
      $issue = $i;
      break;
    }

    if(!empty($issue)){
      return array(
        '#markup' => t('Controller action test successful, found a jira issue with key:' . $issue->key),
      );
    }
    else {
      return array(
        '#markup' => t('Controller action test successful, but no open issue found'),
      );
    }
  }
}
